==> ncbi-blast+_2.11.0+ds.orig.tar.xz: ncbi-blast-2.11.0+-src/c++/include/connect/services/impl/neticache_client_int.hpp <==
#ifndef CONNECT_SERVICES_IMPL__NETICACHE_CLIENT_INT__HPP
#define CONNECT_SERVICES_IMPL__NETICACHE_CLIENT_INT__HPP

/*  $Id: neticache_client_int.hpp 554421 2018-01-03 15:14:01Z sadyrovr $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Author: Rafael Sadyrov
 *
 * File Description:
 *   Internal declarations for NetCache ICache client API.
 *
 */


BEGIN_NCBI_SCOPE


struct NCBI_NET_CACHE_EXPORT CNetICacheClientExt : CNetICacheClient
{
    CNetICacheClientExt() : CNetICacheClient(eVoid) {}
    CNetICacheClientExt(TInstance api)
        : CNetICacheClient(api)
    {
        if (api) SetFlags(fBestReliability);
    }

    CNetICacheClientExt& operator=(TInstance api)
    {
        CNetICacheClient::operator=(api);
        if (api) SetFlags(fBestReliability);
        return *this;
    }

    void ProlongBlobLifetime(const string&, const CTimeout&,
            const CNamedParameterList* optional = NULL);

    SNetCacheAPIImpl* GetNetCacheAPI();
    const SNetCacheAPIImpl* GetNetCacheAPI() const;

    CNetICacheClientExt GetServer(CNetServer::TInstance server);
};


END_NCBI_SCOPE


#endif

==> ncbi-blast+_2.17.0+ds.orig.tar.xz: ncbi-blast-2.17.0+-src/c++/include/connect/services/impl/neticache_client_int.hpp <==
#ifndef CONNECT_SERVICES_IMPL__NETICACHE_CLIENT_INT__HPP
#define CONNECT_SERVICES_IMPL__NETICACHE_CLIENT_INT__HPP

/*  $Id: neticache_client_int.hpp 617404 2020-09-30 19:02:00Z sadyrovr $
 * ===========================================================================
 *
 *                            PUBLIC DOMAIN NOTICE
 *               National Center for Biotechnology Information
 *
 *  This software/database is a "United States Government Work" under the
 *  terms of the United States Copyright Act.  It was written as part of
 *  the author's official duties as a United States Government employee and
 *  thus cannot be copyrighted.  This software/database is freely available
 *  to the public for use. The National Library of Medicine and the U.S.
 *  Government have not placed any restriction on its use or reproduction.
 *
 *  Although all reasonable efforts have been taken to ensure the accuracy
 *  and reliability of the software and data, the NLM and the U.S.
 *  Government do not and cannot warrant the performance or results that
 *  may be obtained by using this software or data. The NLM and the U.S.
 *  Government disclaim all warranties, express or implied, including
 *  warranties of performance, merchantability or fitness for any particular
 *  purpose.
 *
 *  Please cite the author in any work or product based on this material.
 *
 * ===========================================================================
 *
 * Author: Rafael Sadyrov
 *
 * File Description:
 *   Internal declarations for NetCache ICache client API.
 *
 */


BEGIN_NCBI_SCOPE


struct NCBI_NET_CACHE_EXPORT CNetICacheClientExt : CNetICacheClient
{
    CNetICacheClientExt() : CNetICacheClient(eVoid) {}
    CNetICacheClientExt(TInstance api)
        : CNetICacheClient(api)
    {
        if (api) SetFlags(fBestReliability);
    }

    CNetICacheClientExt& operator=(TInstance api)
    {
        CNetICacheClient::operator=(api);
        if (api) SetFlags(fBestReliability);
        return *this;
    }

    using CNetICacheClient::GetReadStream;

    IReader* GetReadStream(
        const string& key,
        const string& subkey,
        int* version,
        size_t* blob_size_ptr,
        const CNamedParameterList* optional = NULL);

    void ProlongBlobLifetime(const string& key, const string& subkey,
            const CTimeout& ttl, const CNamedParameterList* optional = NULL);

    SNetCacheAPIImpl* GetNetCacheAPI();
    const SNetCacheAPIImpl* GetNetCacheAPI() const;

    CNetICacheClientExt GetServer(CNetServer::TInstance server);
};


END_NCBI_SCOPE


#endif
